@@ -2,13 +2,12 @@
 
 import re
 from lxml import etree
-from .httprequest import get_html_session
+from .httprequest import request_session
 from .parser import Parser
 
 
 class Gcolle(Parser):
     source = 'gcolle'
-    imagecut = 4
 
     expr_r18 = '//*[@id="main_content"]/table[1]/tbody/tr/td[2]/table/tbody/tr/td/h4/a[2]/@href'
     expr_number = '//td[contains(text(),"商品番号")]/../td[2]/text()'
@@ -25,11 +24,17 @@ class Gcolle(Parser):
     expr_extrafanart = '//*[@id="cart_quantity"]/table/tr[3]/td/div/img/@src'
     expr_extrafanart2 = '//*[@id="cart_quantity"]/table/tr[3]/td/div/a/img/@src'
 
-    def search(self, number):
-        self.number = number.upper().replace('GCOLLE-','')
-        self.detailurl = 'https://gcolle.net/product_info.php/products_id/' + self.number
-        session = get_html_session(cookies=self.cookies, proxies=self.proxies, verify=self.verify)
-        htmlcode = session.get('https://gcolle.net/product_info.php/products_id/' + number).text
+    def extraInit(self):
+        self.imagecut = 4
+
+    def search(self, number: str):
+        self.number = number.upper().replace('GCOLLE-', '')
+        if self.specifiedUrl:
+            self.detailurl = self.specifiedUrl
+        else:
+            self.detailurl = 'https://gcolle.net/product_info.php/products_id/' + self.number
+        session = request_session(cookies=self.cookies, proxies=self.proxies, verify=self.verify)
+        htmlcode = session.get(self.detailurl).text
         htmltree = etree.HTML(htmlcode)
 
         r18url = self.getTreeElement(htmltree, self.expr_r18)
@@ -66,5 +71,3 @@ class Gcolle(Parser):
         for i in range(len(extrafanart)):
             extrafanart[i] = 'https:' + extrafanart[i]
         return extrafanart
-
-
