@@ -4,16 +4,13 @@
 import re
 from urllib.parse import urljoin
 from lxml import etree
-from .httprequest import get_html_session
+from .httprequest import request_session
 from .parser import Parser
 
 
 class Javdb(Parser):
     source = 'javdb'
 
-    fixstudio = False
-    noauth = False
-
     expr_number = '//strong[contains(text(),"番號")]/../span/text()'
     expr_number2 = '//strong[contains(text(),"番號")]/../span/a/text()'
     expr_title = "/html/head/title/text()"
@@ -44,6 +41,10 @@ class Javdb(Parser):
     expr_uservotes = '//span[@class="score-stars"]/../text()'
     expr_actorphoto = '//strong[contains(text(),"演員:")]/../span/a[starts-with(@href,"/actors/")]'
 
+    def extraInit(self):
+        self.fixstudio = False
+        self.noauth = False
+
     def updateCore(self, core):
         if core.proxies:
             self.proxies = core.proxies
@@ -51,6 +52,8 @@ class Javdb(Parser):
             self.verify = core.verify
         if core.morestoryline:
             self.morestoryline = True
+        if core.specifiedSource == self.source:
+            self.specifiedUrl = core.specifiedUrl
         # special
         if core.dbcookies:
             self.cookies = core.dbcookies
@@ -63,8 +66,11 @@ class Javdb(Parser):
 
     def search(self, number: str):
         self.number = number
-        self.session = get_html_session(cookies=self.cookies, proxies=self.proxies, verify=self.verify)
-        self.detailurl = self.queryNumberUrl(number)
+        self.session = request_session(cookies=self.cookies, proxies=self.proxies, verify=self.verify)
+        if self.specifiedUrl:
+            self.detailurl = self.specifiedUrl
+        else:
+            self.detailurl = self.queryNumberUrl(number)
         self.deatilpage = self.session.get(self.detailurl).text
         if '此內容需要登入才能查看或操作' in self.deatilpage or '需要VIP權限才能訪問此內容' in self.deatilpage:
             self.noauth = True
@@ -173,7 +179,8 @@ class Javdb(Parser):
     def getOutline(self, htmltree):
         if self.morestoryline:
             from .storyline import getStoryline
-            return getStoryline(self.number, self.getUncensored(htmltree))
+            return getStoryline(self.number, self.getUncensored(htmltree),
+                                proxies=self.proxies, verify=self.verify)
         return ''
 
     def getTrailer(self, htmltree):
@@ -193,19 +200,19 @@ class Javdb(Parser):
 
     def getUserRating(self, htmltree):
         try:
-            result = str(self.getTreeElement(htmltree, self.expr_userrating))
-            v = re.findall(r'(\d+|\d+\.\d+)分, 由(\d+)人評價', result)
-            return float(v[0][0])
+            numstrs = self.getTreeElement(htmltree, self.expr_userrating)
+            nums = re.findall('[0-9.]+', numstrs)
+            return float(nums[0])
         except:
-            return
+            return ''
 
     def getUserVotes(self, htmltree):
         try:
-            result = str(self.getTreeElement(htmltree, self.expr_uservotes))
-            v = re.findall(r'(\d+|\d+\.\d+)分, 由(\d+)人評價', result)
-            return int(v[0][1])
+            result = self.getTreeElement(htmltree, self.expr_uservotes)
+            v = re.findall('[0-9.]+', result)
+            return int(v[1])
         except:
-            return
+            return ''
 
     def getaphoto(self, url, session):
         html_page = session.get(url).text
