@@ -16,6 +16,10 @@ class Mv91(Parser):
     expr_tags = '//div[@class="player-tag"]/text()'
     expr_actor = '//p[@class="player-name"]/text()'
 
+    def extraInit(self):
+        self.imagecut = 0
+        self.uncensored = True
+
     def getHtmlTree(self, url, type=None):
         self.htmlcode = self.getHtml(url, type)
         if self.htmlcode == 404:
@@ -53,8 +57,8 @@ class Mv91(Parser):
                 result = str(finds[0][0])
             else:
                 result = ' '.join(title.replace('/',' ').split())
-                result = result.split()[0].replace('「预告」','')
-            return result.strip()
+                result = result.split()[0]
+            return result.replace('「预告」','').strip('/ ')
         except:
             return ''
 
